Issues a deprecation warning when an old argument is used, and resolves which value to return (new takes precedence over old).
Arguments
- new_val
Value provided for the new argument (may be NULL).
- old_val
Value provided for the deprecated argument (may be NULL).
- old_name
Name of the deprecated argument for the warning message.
- new_name
Name of the replacement argument for the warning message.
- fn_name
Name of the calling function for the warning message.